@@ -19,7 +19,7 @@ class VKTests(OAuth2TestsMixin, TestCase):
         "last_name": "I.",
         "phone": "79991234567",
         "avatar": "http://avatar.com/12345678",
-        "email": "ivan_i123@vk.com",
+        "email": "ivan_i123@vk.ru",
         "sex": 2,
         "verified": false,
         "birthday": "01.01.2000"
@@ -29,7 +29,7 @@ class VKTests(OAuth2TestsMixin, TestCase):
         )
 
     def get_expected_to_str(self):
-        return "ivan_i123@vk.com"
+        return "ivan_i123@vk.ru"
 
     def get_login_response_json(self, with_refresh_token=True):
         return """
